raytraverse.sky
==========================================================

skycalc
---------------------------------

.. automodule:: raytraverse.sky.skycalc
    :members:
    :undoc-members:
    :show-inheritance:

SkyData
---------------------------------

.. autoclass:: raytraverse.sky.SkyData
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SolarBoundary
---------------------------------

.. autoclass:: raytraverse.sky.SolarBoundary
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

Suns
---------------------------------

.. autoclass:: raytraverse.sky.Suns
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunsLoc
---------------------------------

.. autoclass:: raytraverse.sky.SunsLoc
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunsPos
---------------------------------

.. autoclass:: raytraverse.sky.SunsPos
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
